==> haskell-hls-refactor-plugin-2.1.0.0-99-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-LKcA20csAJh73cRgHCuunT
key:                  hls-refactor-plugin-2.1.0.0-LKcA20csAJh73cRgHCuunT
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  8e8b151a70bb174d398a48d45fa8347c
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-LKcA20csAJh73cRgHCuunT
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    ghcide-2.1.0.0-BlCpiz4ZHvtIqUTiKV6UyX
    hls-graph-2.1.0.0-5t3ebukJcC8H3T2BKlhdh9
    hls-plugin-api-2.1.0.0-IyHsVCiLch7D25xEM5t6Zs
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    regex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    retrie-1.2.3-3BFf1hlshVm6m2JkJ2mw4i
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2
    text-rope-0.3-Gq8oRIBjiYqAbKRkuHVfVA time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-refactor-plugin-2.1.0.0-100-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-refactor-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-refactor-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-refactor-plugin-2.1.0.0-3a2DGLmo4jC4uYcr4QLr53
key:                  hls-refactor-plugin-2.1.0.0-3a2DGLmo4jC4uYcr4QLr53
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           zubin.duggal@gmail.com
author:               The Haskell IDE Team
synopsis:             Exactprint refactorings for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  9de6bc1d4d3e6e2258b720ca404f26af
exposed:              True
exposed-modules:
    Development.IDE.GHC.Compat.ExactPrint Development.IDE.GHC.Dump
    Development.IDE.GHC.ExactPrint Development.IDE.Plugin.CodeAction
    Development.IDE.Plugin.CodeAction.Util

hidden-modules:
    Development.IDE.Plugin.CodeAction.Args
    Development.IDE.Plugin.CodeAction.ExactPrint
    Development.IDE.Plugin.CodeAction.PositionIndexed
    Development.IDE.Plugin.Plugins.AddArgument
    Development.IDE.Plugin.Plugins.Diagnostic
    Development.IDE.Plugin.Plugins.FillHole
    Development.IDE.Plugin.Plugins.FillTypeWildcard
    Development.IDE.Plugin.Plugins.ImportUtils

import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-refactor-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-refactor-plugin
hs-libraries:         HShls-refactor-plugin-2.1.0.0-3a2DGLmo4jC4uYcr4QLr53
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz deepseq-1.4.8.1
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy ghc-9.6.6 ghc-boot-9.6.6
    ghc-exactprint-1.7.1.0-F0i4FugjRs4FGSGCq308uf
    ghcide-2.1.0.0-FnivsoqaY804ocwiGSGs4S
    hls-graph-2.1.0.0-2K7OAPbw31L8NzoSrWGIDe
    hls-plugin-api-2.1.0.0-DLt74c0m6zn5iIl3F9hXDn
    lens-5.3.3-HAYf6JaG0qX5o8D7xn9NgM
    lsp-2.1.0.0-FDkJ3hOfaOyD0G3xXwdyeX mtl-2.3.1
    parser-combinators-1.3.0-20UTEUZ5CKDJdRu747ID48
    regex-applicative-0.3.4-IOg9SG4NfoV1BVfdLhHuSS
    regex-tdfa-1.3.2.5-ATqtlBuPETHJOcVIKuiav2
    retrie-1.2.3-3BFf1hlshVm6m2JkJ2mw4i
    syb-0.7.3-7GPFF4ffw0kLXaCjDkD2wt text-2.0.2
    text-rope-0.3-Gq8oRIBjiYqAbKRkuHVfVA time-1.12.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:
    /usr/share/doc/haskell-hls-refactor-plugin/html/hls-refactor-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-refactor-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
